@@ -171,7 +171,8 @@ base_converter_params = {
         "to_python_dict": {
             "double precision": "float",
             "int": "int",
-            "json": "json",
+            "long varbinary": "json",
+            "blob": "json",
             "boolean": "bool",
         },
     },
