@@ -163,13 +163,15 @@ class DataBaseWorker:
         :return:
         """
         cursor = self.engine.raw_connection().cursor()
+        keys_data = list(data[0].keys())
         columns = self.get_columns(table_name)
-        fields_json = [key for key in columns if columns[key] in ("long varbinary", "blob")]
+        keys_data = [key for key in keys_data if key in columns]
+        fields_json = [key for key in keys_data if columns[key] in ("long varbinary", "blob")]
         vertica_insert(
             cursor=cursor,
             target=self.schema + "." + table_name,
             fields_json=fields_json,
-            fields=list(columns.keys()),
+            fields=keys_data,
             data=data,
         )
 
