@@ -3,7 +3,7 @@ import datetime
 
 
 def myconverter(o):
-    if isinstance(o, datetime.datetime):
+    if isinstance(o, datetime.date) or isinstance(o, datetime.datetime):
         return o.__str__()
 
 
